@@ -8,8 +8,11 @@ from rest_framework.exceptions import ValidationError
 from config import settings as store_settings
 from ob_dj_store.core.stores.models import (
     Category,
+    CountryPaymentMethod,
     Favorite,
     Order,
+    Partner,
+    PartnerAuthInfo,
     PaymentMethod,
     Product,
     ProductVariant,
@@ -17,7 +20,7 @@ from ob_dj_store.core.stores.models import (
 )
 from ob_dj_store.core.stores.models._inventory import Inventory
 from ob_dj_store.core.stores.models._wallet import Wallet
-from ob_dj_store.core.stores.utils import validate_currency
+from ob_dj_store.core.stores.utils import get_currency_by_country, validate_currency
 
 
 class StoreFilter(filters.FilterSet):
@@ -268,9 +271,45 @@ class WalletFilter(filters.FilterSet):
             validate_currency,
         ],
     )
+    country = filters.CharFilter(method="by_country")
 
     class Meta:
         models = Wallet
 
     def by_currency(self, queryset, name, value):
         return queryset.filter(currency=value)
+
+    def by_country(self, queryset, name, value):
+        if value:
+            currency = get_currency_by_country(value)
+            return queryset.filter(currency=currency)
+
+
+class PartnerFilter(filters.FilterSet):
+    country = filters.CharFilter(method="by_country")
+
+    class Meta:
+        models = Partner
+
+    def by_country(self, queryset, name, value):
+        if value:
+            return queryset.filter(country=value)
+
+
+class PartnerAuthInfoFilter(filters.FilterSet):
+    class Meta:
+        models = PartnerAuthInfo
+        fields = [
+            "partner",
+        ]
+
+
+class CountryPaymentMethodFilter(filters.FilterSet):
+    country = filters.CharFilter(method="by_country")
+
+    class Meta:
+        models = CountryPaymentMethod
+
+    def by_country(self, queryset, name, value):
+        if value:
+            return queryset.filter(country=value)
