@@ -1,5 +1,4 @@
 import calendar
-import json
 import logging
 import typing
 from datetime import timedelta
@@ -16,6 +15,7 @@ from django.shortcuts import get_object_or_404
 from django.utils.module_loading import import_string
 from django.utils.timezone import localtime, now
 from django.utils.translation import gettext_lazy as _
+from ob_dj_otp.core.otp.models import OneTruePairing
 from phonenumber_field.phonenumber import to_python
 from rest_framework import serializers
 
@@ -26,6 +26,8 @@ from ob_dj_store.core.stores.models import (
     Cart,
     CartItem,
     Category,
+    CountryPaymentMethod,
+    Discount,
     Favorite,
     FavoriteExtra,
     Feedback,
@@ -35,6 +37,9 @@ from ob_dj_store.core.stores.models import (
     Order,
     OrderHistory,
     OrderItem,
+    Partner,
+    PartnerAuthInfo,
+    PartnerOTPAuth,
     Payment,
     PaymentMethod,
     PhoneContact,
@@ -51,24 +56,79 @@ from ob_dj_store.core.stores.models import (
     WalletTransaction,
 )
 from ob_dj_store.core.stores.models._inventory import Inventory
-from ob_dj_store.core.stores.utils import distance
+from ob_dj_store.core.stores.utils import PartnerAuth, distance
 
 logger = logging.getLogger(__name__)
 
+from rest_framework import serializers
 
-class AttributeChoiceSerializer(serializers.ModelSerializer):
+
+class ArabicFieldsMixin:
+    """
+    Serializer mixin to include or exclude Arabic fields based on the request header.
+    """
+
+    ARABIC_LANGUAGE_CODE = "AR"
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.arabic_field_suffixes = [
+            "_arabic",
+            "arabic_",
+        ]  # Add other suffixes as needed
+
+    def should_include_arabic_fields(self, request):
+        """
+        Check if the request header includes the Arabic language.
+        """
+        language_header = request.META.get("HTTP_LANGUAGE", "").upper()
+        return language_header == self.ARABIC_LANGUAGE_CODE
+
+    def get_fields(self):
+        """
+        Override the get_fields method to include or exclude Arabic fields.
+        """
+        fields = super().get_fields()
+        request = self.context.get("request")
+        if request and self.should_include_arabic_fields(request):
+            for field_name in list(fields.keys()):
+                # Check if the field has an Arabic version based on suffixes
+                for suffix in self.arabic_field_suffixes:
+                    if field_name.endswith(suffix) or field_name.startswith(suffix):
+                        # Exclude the original field
+                        original_field_name = field_name.replace(suffix, "")
+                        fields.pop(original_field_name, None)
+        return fields
+
+
+class AttributeChoiceSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     class Meta:
         model = AttributeChoice
         fields = (
             "id",
             "name",
-            "price",
             "label",
             "is_default",
         )
 
+    def to_representation(self, instance):
+        data = super().to_representation(instance)
+        store = self.context.get("store", None)
+        if not store and self.context.get("view", None):
+            store = self.context["view"].kwargs.get("store_pk", None)
+        if store:
+            try:
+                attribute_inventory = instance.attribute_inventory.get(store=store)
+                data["price"] = attribute_inventory.price
+            except ObjectDoesNotExist:
+                raise serializers.ValidationError(
+                    f"AttributeChoice(PK={instance.pk}) doesnt have inventory at Store(PK={store})"
+                )
 
-class AttributeSerializer(serializers.ModelSerializer):
+        return data
+
+
+class AttributeSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     attribute_choices = AttributeChoiceSerializer(many=True, read_only=True)
 
     class Meta:
@@ -102,13 +162,13 @@ class InventoryValidationMixin:
         return validated_data
 
 
-class OpeningHourSerializer(serializers.ModelSerializer):
+class OpeningHourSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     class Meta:
         model = OpeningHours
         fields = "__all__"
 
 
-class ShippingMethodSerializer(serializers.ModelSerializer):
+class ShippingMethodSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     class Meta:
         model = ShippingMethod
         fields = "__all__"
@@ -148,24 +208,42 @@ class OrderItemSerializer(InventoryValidationMixin, serializers.ModelSerializer)
 
     def to_representation(self, instance):
         representation = super().to_representation(instance)
+        if not instance.order.store:
+            raise serializers.ValidationError(
+                f"Physical Order(PK={instance.order.pk}) doesnt not have store object"
+            )
+        self.context["store"] = instance.order.store
         representation["attribute_choices"] = AttributeChoiceSerializer(
-            instance.attribute_choices.all(), many=True
+            instance.attribute_choices.all(), many=True, context=self.context
         ).data
 
         return representation
 
 
+class DiscountSerializer(serializers.ModelSerializer):
+    discount_rate_perc = serializers.SerializerMethodField()
+
+    class Meta:
+        model = Discount
+        fields = ("id", "discount_rate", "is_active", "discount_rate_perc")
+
+    def get_discount_rate_perc(self, obj):
+        return obj.discount_rate * 100
+
+
 class OrderSerializer(serializers.ModelSerializer):
     items = OrderItemSerializer(many=True, read_only=True)
     history = OrderHistorySerializer(many=True, read_only=True)
     estimated_timeline = serializers.SerializerMethodField()
     store_name = serializers.SerializerMethodField()
+    discount = DiscountSerializer(read_only=True)
 
     class Meta:
         model = Order
         fields = (
             "id",
             "store",
+            "discount",
             "shipping_method",
             "payment_method",
             "shipping_address",
@@ -176,6 +254,7 @@ class OrderSerializer(serializers.ModelSerializer):
             "total_amount",
             "preparation_time",
             "estimated_timeline",
+            "get_discount_amount",
             "history",
             "car_id",
             "pickup_time",
@@ -320,11 +399,6 @@ class OrderSerializer(serializers.ModelSerializer):
             attrs["extra_infos"] = {}
         stores = Store.objects.filter(store_items__cart=user.cart).distinct()
         gift_details = attrs["extra_infos"].get("gift_details", None)
-        apple_pay_attr = attrs["extra_infos"].get("apple_pay", None)
-        if apple_pay_attr:
-            token_data = apple_pay_attr.encode("utf-8").decode("unicode_escape")
-            new_token_data = json.loads(token_data)
-            attrs["extra_infos"]["apple_pay"] = new_token_data
         if gift_details:
             self._validate_digital_product(gift_details, attrs)
             currency = gift_details["currency"]
@@ -471,7 +545,7 @@ class CreateOrderResponseSerializer(serializers.Serializer):
     pickup_time = serializers.DateTimeField(write_only=True, required=False)
 
 
-class ProductTagSerializer(serializers.ModelSerializer):
+class ProductTagSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     class Meta:
         model = ProductTag
         fields = (
@@ -482,7 +556,7 @@ class ProductTagSerializer(serializers.ModelSerializer):
         )
 
 
-class ProductAttributeSerializer(serializers.ModelSerializer):
+class ProductAttributeSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     attribute_choices = AttributeChoiceSerializer(many=True)
 
     class Meta:
@@ -499,7 +573,7 @@ class ProductAttributeSerializer(serializers.ModelSerializer):
         )
 
 
-class ProductVariantSerializer(serializers.ModelSerializer):
+class ProductVariantSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     product_attributes = ProductAttributeSerializer(many=True)
     is_primary = serializers.SerializerMethodField()
     inventory = serializers.SerializerMethodField()
@@ -535,7 +609,9 @@ class ProductVariantSerializer(serializers.ModelSerializer):
         return inventory
 
 
-class CartItemSerializer(InventoryValidationMixin, serializers.ModelSerializer):
+class CartItemSerializer(
+    InventoryValidationMixin, ArabicFieldsMixin, serializers.ModelSerializer
+):
     image = serializers.SerializerMethodField()
     inventory_quantity = serializers.SerializerMethodField()
     is_uncountable = serializers.SerializerMethodField()
@@ -632,9 +708,9 @@ class CartItemSerializer(InventoryValidationMixin, serializers.ModelSerializer):
             instance=instance.product_variant
         ).data
         data["product_name"] = instance.product_variant.product.name
+        self.context["store"] = instance.store
         data["attribute_choices"] = AttributeChoiceSerializer(
-            instance.attribute_choices.all(),
-            many=True,
+            instance.attribute_choices.all(), many=True, context=self.context
         ).data
         return data
 
@@ -653,6 +729,9 @@ class CartSerializer(serializers.ModelSerializer):
             "total_price",
             "tax_amount",
             "total_price_with_tax",
+            "discount_offer_amount",
+            "total_price_with_discount",
+            "full_price",
         )
         read_only_fields = (
             "id",
@@ -724,7 +803,7 @@ class FavoriteMixin:
         return self.favorites
 
 
-class ProductSerializer(FavoriteMixin, serializers.ModelSerializer):
+class ProductSerializer(ArabicFieldsMixin, FavoriteMixin, serializers.ModelSerializer):
     product_variants = ProductVariantSerializer(many=True)
     product_images = ProductMediaSerializer(many=True, source="images")
     default_variant = ProductVariantSerializer(read_only=True, many=False)
@@ -750,7 +829,7 @@ class ProductSerializer(FavoriteMixin, serializers.ModelSerializer):
         return data
 
 
-class ProductListSerializer(serializers.ModelSerializer):
+class ProductListSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     product_images = ProductMediaSerializer(many=True, source="images")
 
     class Meta:
@@ -804,7 +883,7 @@ class SubCategorySerializer(serializers.ModelSerializer):
         return False
 
 
-class CategorySerializer(serializers.ModelSerializer):
+class CategorySerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     products = ProductListSerializer(many=True)
     subcategories = SubCategorySerializer(many=True, read_only=True)
     is_available = serializers.SerializerMethodField()
@@ -928,7 +1007,7 @@ class PhoneContactSerializer(serializers.ModelSerializer):
         )
 
 
-class StoreSerializer(FavoriteMixin, serializers.ModelSerializer):
+class StoreSerializer(ArabicFieldsMixin, FavoriteMixin, serializers.ModelSerializer):
 
     opening_hours = serializers.SerializerMethodField()
     phone_contacts = serializers.SerializerMethodField()
@@ -1080,7 +1159,7 @@ class StoreSerializer(FavoriteMixin, serializers.ModelSerializer):
         return super().to_representation(instance)
 
 
-class PaymentMethodSerializer(serializers.ModelSerializer):
+class PaymentMethodSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     class Meta:
         model = PaymentMethod
         fields = (
@@ -1111,7 +1190,7 @@ class TaxSerializer(serializers.ModelSerializer):
         )
 
 
-class StoreListSerializer(serializers.ModelSerializer):
+class StoreListSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     class Meta:
         model = Store
         fields = "__all__"
@@ -1148,7 +1227,7 @@ def get_favorite_extras_models():
     return extras_list
 
 
-class FavoriteExtraSerializer(serializers.ModelSerializer):
+class FavoriteExtraSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     content_object = GenericSerializer(read_only=True)
     object_id = serializers.IntegerField(min_value=1)
     object_type = serializers.ChoiceField(
@@ -1175,7 +1254,7 @@ class FavoriteExtraSerializer(serializers.ModelSerializer):
         return data
 
 
-class FavoriteSerializer(serializers.ModelSerializer):
+class FavoriteSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     content_object = GenericSerializer(read_only=True)
     extras = FavoriteExtraSerializer(many=True)
     object_id = serializers.IntegerField(min_value=1, required=False)
@@ -1193,6 +1272,7 @@ class FavoriteSerializer(serializers.ModelSerializer):
             "content_object",
             "extras",
             "object_id",
+            "extra_info",
             "object_type",
             "name",
             "is_available_in_store",
@@ -1226,6 +1306,7 @@ class FavoriteSerializer(serializers.ModelSerializer):
         return data
 
     def _lookup_validation(self, data):
+        extra_info = data.get("extra_info", None)
         content_type = ContentType.objects.get_for_model(data["content_object"])
         queryset = Favorite.objects.filter(
             content_type=content_type,
@@ -1240,7 +1321,10 @@ class FavoriteSerializer(serializers.ModelSerializer):
                 content_objects = [
                     instance.content_object for instance in favorite.extras.all()
                 ]
-                if set(data["extras"]) == set(content_objects):
+                if (
+                    set(data["extras"]) == set(content_objects)
+                    and favorite.extra_info == extra_info
+                ):
                     raise serializers.ValidationError(
                         _(f"You cannot favorite the same item twice")
                     )
@@ -1309,6 +1393,7 @@ class FavoriteSerializer(serializers.ModelSerializer):
             "content_object": object_instance,
             "extras": extras,
             "name": validated_data["name"],
+            "extra_info": validated_data.get("extra_info", None),
         }
         self._lookup_validation(validated_data)
         return validated_data
@@ -1319,6 +1404,7 @@ class FavoriteSerializer(serializers.ModelSerializer):
                 content_object=validated_data["content_object"],
                 user=self.context["request"].user,
                 name=validated_data["name"],
+                extra_info=validated_data["extra_info"],
                 extras=validated_data["extras"],
             )
         except ValidationError as e:
@@ -1329,6 +1415,7 @@ class FavoriteSerializer(serializers.ModelSerializer):
         try:
             favorite = instance.update_favorite(
                 validated_data["name"],
+                validated_data["extra_info"],
                 validated_data["extras"],
             )
         except ValidationError as e:
@@ -1342,7 +1429,7 @@ class WalletMediaSerializer(serializers.ModelSerializer):
         fields = "__all__"
 
 
-class WalletSerializer(serializers.ModelSerializer):
+class WalletSerializer(ArabicFieldsMixin, serializers.ModelSerializer):
     class Meta:
         model = Wallet
         fields = [
@@ -1372,6 +1459,7 @@ class WalletTopUpSerializer(serializers.Serializer):
                 store_settings.TAP_KNET,
                 store_settings.TAP_ALL,
                 store_settings.APPLE_PAY,
+                store_settings.GOOGLE_PAY,
             ]
         ),
         required=True,
@@ -1456,3 +1544,168 @@ class OrderDataSerializer(serializers.ModelSerializer):
 
     def get_shipping_method_name(self, obj):
         return obj.shipping_method.name if obj.shipping_method else None
+
+
+class PartnerOTPRequestSerializer(serializers.ModelSerializer):
+    email = serializers.EmailField(required=True)
+
+    class Meta:
+        model = PartnerOTPAuth
+        exclude = ("user", "otp", "partner")
+
+    def _validate_old_valid_verification_code(self, attrs):
+        # Validate there is unused OTP code
+        timeout = now() - timedelta(seconds=getattr(settings, "OTP_TIMEOUT", 3 * 60))
+        qs = PartnerOTPAuth.objects.filter(
+            created_at__gte=timeout, email=attrs["email"]
+        )
+        if qs.exists():
+            # TODO: Add a mechanism to force a new code request
+            # with a field called "force" with checking that he didn't call this api to many times
+            seconds_left = (
+                timedelta(seconds=getattr(settings, "OTP_TIMEOUT", 3 * 60))
+                - (now() - qs.last().created_at)
+            ).total_seconds()
+            minutes_left = int(seconds_left) // 60 or 1
+            raise serializers.ValidationError(
+                _(
+                    "We sent a verification code please wait for "
+                    "{minutes} minutes; before requesting a new code."
+                ).format(minutes=minutes_left)
+            )
+
+    def validate(self, attrs):
+        attrs = super().validate(attrs)
+        try:
+            partner_auth = PartnerAuth(attrs["email"])
+        except ValidationError as e:
+            raise serializers.ValidationError(detail=e.messages)
+        partner = partner_auth.partner
+        if partner.auth_method != Partner.AuthMethods.OTP:
+            raise serializers.ValidationError(
+                _(f"{partner.name} does not support OTP as Auth Method")
+            )
+        self._validate_old_valid_verification_code(attrs)
+        attrs["partner"] = partner
+        return attrs
+
+    def create(self, validated_data):
+        user = self.context["view"].request.user
+        otp = OneTruePairing.objects.create(
+            user=user, usage=OneTruePairing.Usages.auth, email=validated_data["email"]
+        )
+        partner_otp_auth = PartnerOTPAuth.objects.create(
+            user=self.context["view"].request.user,
+            partner=validated_data["partner"],
+            otp=otp,
+            email=validated_data["email"],
+        )
+        return partner_otp_auth
+
+
+class PartnerSerializer(serializers.ModelSerializer):
+    discount = DiscountSerializer()
+    stores = StoreListSerializer(many=True)
+
+    class Meta:
+        model = Partner
+        fields = ("id", "name", "stores", "auth_method", "country", "discount")
+
+
+class PartnerAuthInfoSerializer(serializers.ModelSerializer):
+    partner = PartnerSerializer(read_only=True)
+    promotion_code = serializers.IntegerField(write_only=True, required=False)
+    otp_code = serializers.IntegerField(write_only=True, required=False)
+    email = serializers.EmailField(write_only=True, required=True)
+
+    class Meta:
+        model = PartnerAuthInfo
+        fields = (
+            "id",
+            "user",
+            "email",
+            "otp_code",
+            "promotion_code",
+            "partner",
+            "authentication_expires",
+            "status",
+            "created_at",
+            "updated_at",
+        )
+        extra_kwargs = {
+            "user": {"read_only": True},
+            "email": {"read_only": True},
+            "status": {"read_only": True},
+            "authentication_expires": {"read_only": True},
+        }
+
+    def _validate_partner_auth_method(self, attrs):
+        partner = attrs["partner"]
+        user = self.context["view"].request.user
+        if partner.auth_method == Partner.AuthMethods.OTP:
+            otp_code = attrs.get("otp_code", None)
+            if otp_code == None:
+                raise serializers.ValidationError(_("OTP code is required"))
+            timeout = now() - timedelta(
+                seconds=getattr(settings, "OTP_TIMEOUT", 3 * 60)
+            )
+            try:
+                otp = OneTruePairing.objects.filter(
+                    verification_code=otp_code,
+                    status=OneTruePairing.Statuses.init,
+                    created_at__gte=timeout,
+                ).get(
+                    email=attrs["email"],
+                    partner_otp_auth__partner=partner,
+                    user=user,
+                )
+                self.context["otp"] = otp
+            except ObjectDoesNotExist as e:
+                raise serializers.ValidationError(
+                    _(f"Invalid verification code.")
+                ) from e
+
+        elif partner.auth_method == Partner.AuthMethods.CODE:
+            promotion_code = attrs.get("promotion_code", None)
+            if promotion_code == None:
+                raise serializers.ValidationError(_("Promotion code is required"))
+            elif not partner.promotion_code:
+                logger.error(f"{partner.name} does not have promotion code")
+                raise serializers.ValidationError(_("Promotion code is not working"))
+            elif partner.promotion_code != promotion_code:
+                raise serializers.ValidationError(_("Promotion code is invalid"))
+        return attrs
+
+    def validate(self, attrs):
+        attrs = super().validate(attrs)
+        try:
+            partner_auth = PartnerAuth(attrs["email"])
+        except ValidationError as e:
+            raise serializers.ValidationError(detail=e.messages)
+        attrs["partner"] = partner_auth.partner
+        self._validate_partner_auth_method(attrs)
+        return attrs
+
+    def create(self, validated_data):
+        user = self.context["view"].request.user
+        partner = validated_data["partner"]
+        if partner.auth_method == Partner.AuthMethods.OTP:
+            otp = self.context["otp"]
+            otp.status = OneTruePairing.Statuses.used
+            otp.save()
+        partner_auth_info = PartnerAuthInfo.objects.update_or_create(
+            user=user,
+            defaults={
+                "partner": partner,
+                "email": validated_data["email"],
+            },
+        )
+        return partner_auth_info
+
+
+class CountryPaymentMethodSerialzier(serializers.ModelSerializer):
+    payment_methods = PaymentMethodSerializer(read_only=True, many=True)
+
+    class Meta:
+        model = CountryPaymentMethod
+        fields = ("id", "country", "payment_methods")
