@@ -24,8 +24,11 @@ from rest_framework_nested.viewsets import NestedViewSetMixin
 from config import settings as store_settings
 from ob_dj_store.apis.stores.filters import (
     CategoryFilter,
+    CountryPaymentMethodFilter,
     InventoryFilter,
     OrderFilter,
+    PartnerAuthInfoFilter,
+    PartnerFilter,
     PaymentMethodFilter,
     ProductFilter,
     StoreFilter,
@@ -36,11 +39,15 @@ from ob_dj_store.apis.stores.rest.serializers.serializers import (
     CartItemSerializer,
     CartSerializer,
     CategorySerializer,
+    CountryPaymentMethodSerialzier,
     CreateOrderResponseSerializer,
     FavoriteSerializer,
     FeedbackSerializer,
     InventorySerializer,
     OrderSerializer,
+    PartnerAuthInfoSerializer,
+    PartnerOTPRequestSerializer,
+    PartnerSerializer,
     PaymentMethodSerializer,
     PaymentSerializer,
     ProductListSerializer,
@@ -62,9 +69,12 @@ from ob_dj_store.core.stores.models import (
     Cart,
     CartItem,
     Category,
+    CountryPaymentMethod,
     Favorite,
     FeedbackConfig,
     Order,
+    Partner,
+    PartnerAuthInfo,
     Payment,
     PaymentMethod,
     PhoneContact,
@@ -1259,3 +1269,176 @@ class WalletViewSet(
 
         serializer = self.get_serializer(queryset, many=True)
         return Response(serializer.data)
+
+
+class PartnerAuthInfoViewSet(
+    mixins.CreateModelMixin,
+    mixins.RetrieveModelMixin,
+    mixins.DestroyModelMixin,
+    viewsets.GenericViewSet,
+):
+    queryset = PartnerAuthInfo.objects.all()
+    permission_classes = [
+        permissions.IsAuthenticated,
+    ]
+    serializer_class = PartnerAuthInfoSerializer
+    filterset_class = PartnerAuthInfoFilter
+
+    def get_object(self):
+        return get_object_or_404(PartnerAuthInfo, user=self.request.user)
+
+    @swagger_auto_schema(
+        operation_summary="Send an OTP for PartnerAuthInfo",
+        operation_description="""
+                Send an OTP for PartnerAuthInfo
+            """,
+        tags=[
+            "Partner",
+        ],
+    )
+    @action(
+        methods=[
+            "POST",
+        ],
+        detail=False,
+        url_path="send-otp",
+        serializer_class=PartnerOTPRequestSerializer,
+    )
+    def send_otp(
+        self, request: Request, *args: typing.Any, **kwargs: typing.Any
+    ) -> Response:
+        serializer = self.get_serializer(data=request.data)
+        serializer.is_valid(raise_exception=True)
+        serializer.save()
+        headers = self.get_success_headers(serializer.data)
+        return Response(
+            {"result": "ok"}, status=status.HTTP_201_CREATED, headers=headers
+        )
+
+    @swagger_auto_schema(
+        operation_summary="verify Partner's Authentication ",
+        operation_description="""
+                verify Partner's Authentication for different auth methods
+            """,
+        tags=[
+            "Partner",
+        ],
+    )
+    @action(
+        methods=[
+            "POST",
+        ],
+        detail=False,
+        url_path="",
+        serializer_class=PartnerAuthInfoSerializer,
+    )
+    def verify(
+        self, request: Request, *args: typing.Any, **kwargs: typing.Any
+    ) -> Response:
+        serializer = self.get_serializer(data=request.data)
+        serializer.is_valid(raise_exception=True)
+        serializer.save()
+        headers = self.get_success_headers(serializer.data)
+        return Response(
+            serializer.data, status=status.HTTP_201_CREATED, headers=headers
+        )
+
+    @swagger_auto_schema(
+        operation_summary="Retrieve User partner Auth",
+        operation_description="""
+                Retrieve User partner Auth
+            """,
+        tags=[
+            "Partner",
+        ],
+    )
+    def retrieve(
+        self, request: Request, *args: typing.Any, **kwargs: typing.Any
+    ) -> Response:
+        return super().retrieve(request=request, *args, **kwargs)
+
+    @swagger_auto_schema(
+        operation_summary="Delete User partner Auth",
+        operation_description="""
+                Delete User partner Auth
+            """,
+        tags=[
+            "Partner",
+        ],
+    )
+    def destroy(self, request, *args, **kwargs):
+        return super().destroy(request, *args, **kwargs)
+
+
+class PartnerViewSet(
+    mixins.ListModelMixin,
+    mixins.RetrieveModelMixin,
+    viewsets.GenericViewSet,
+):
+    queryset = Partner.objects.all()
+    permission_classes = [
+        permissions.IsAuthenticated,
+    ]
+    serializer_class = PartnerSerializer
+    filterset_class = PartnerFilter
+
+    @swagger_auto_schema(
+        operation_summary="Retrieve Partner",
+        operation_description="""
+                retireve a partner
+            """,
+        tags=[
+            "Partner",
+        ],
+    )
+    def retrieve(
+        self, request: Request, *args: typing.Any, **kwargs: typing.Any
+    ) -> Response:
+        return super().retrieve(request=request, *args, **kwargs)
+
+    @swagger_auto_schema(
+        operation_summary="List Partners",
+        operation_description="""
+                List  partners
+            """,
+        tags=[
+            "Partner",
+        ],
+    )
+    def list(self, request, *args, **kwargs):
+        return super().list(request, *args, **kwargs)
+
+
+class CountryPaymentMethodsViewSet(
+    mixins.ListModelMixin, mixins.RetrieveModelMixin, viewsets.GenericViewSet
+):
+    queryset = CountryPaymentMethod.objects.active()
+    serializer_class = CountryPaymentMethodSerialzier
+    filterset_class = CountryPaymentMethodFilter
+    permission_classes = [
+        permissions.AllowAny,
+    ]
+
+    @swagger_auto_schema(
+        operation_summary="List Country Payment Methods",
+        operation_description="""
+                List Country Payment Methods
+            """,
+        tags=[
+            "Store",
+        ],
+    )
+    def list(self, request, *args, **kwargs):
+        return super().list(request, *args, **kwargs)
+
+    @swagger_auto_schema(
+        operation_summary="Retrieve Country Payment Method",
+        operation_description="""
+                Retrieve Country Payment Method
+            """,
+        tags=[
+            "Store",
+        ],
+    )
+    def retrieve(self, request, *args, **kwargs):
+        return super().retrieve(request, *args, **kwargs)
