@@ -29,6 +29,8 @@ class TapPayment(models.Model):
     class Sources(models.TextChoices):
         CREDIT_CARD = "src_card", _("Credit Card")
         KNET = "src_kw.knet", _("KNet")
+        APPLE_PAY = "apple_pay", _("Apple pay")
+        GOOGLE_PAY = "google_pay", _("Google pay")
         ALL = "src_all", _("All")
 
     status = models.CharField(max_length=100, choices=Status.choices)
@@ -103,7 +105,12 @@ class TapPayment(models.Model):
         return self.callback_response["currency"] if self.callback_response else None
 
     def callback_update(self, tap_payload):
-        if self.callback_response == None:
+        apple_pay = getattr(settings, "APPLE_PAY", "apple_pay")
+        google_pay = getattr(settings, "GOOGLE_PAY", "google_pay")
+        if self.callback_response == None and self.source not in [
+            apple_pay,
+            google_pay,
+        ]:
             self.result = tap_payload["status"]
             self.callback_response = tap_payload
             self.status = tap_payload["status"]
