@@ -89,14 +89,17 @@ def initiate_payment(
 
     order = payment.orders.all().first()
     extra_infos = order.extra_infos
+    display_source = None
     if source in [
         settings.APPLE_PAY,
+        settings.GOOGLE_PAY,
     ]:
         token_data = extra_infos.get("tap_token")
         if not token_data:
             raise ValidationError(
                 _(f"Order(PK={order.pk}) does not have tap_token for {source} payment")
             )
+        display_source = source
         source = token_data["id"]
     tap_customer = retrieve_customer_id(user)
     payload = {
@@ -150,6 +153,6 @@ def initiate_payment(
         "charge_id": charge_id,
         "payment_url": payment_url,
         "init_response": tap_response,
-        "source": source,
+        "source": display_source if display_source else source,
         "status": status,
     }
