@@ -6,6 +6,7 @@ from decimal import Decimal
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist, ValidationError
 from django.db import models
+from django.utils.timezone import now
 from django.utils.translation import gettext_lazy as _
 
 from config import settings
@@ -63,7 +64,7 @@ class PaymentManager(models.Manager):
                 {"order", _("You cannot perform payment without items")}
             )
         try:
-            if orders[0].store:
+            if orders[0].store and orders[0].type_of_order == "PHYSICAL":
                 kwargs["payment_tax"] = Tax.objects.get(
                     country=orders[0].store.address.country, is_active=True
                 )
@@ -80,6 +81,7 @@ class PaymentManager(models.Manager):
             settings.TAP_KNET,
             settings.TAP_ALL,
             settings.APPLE_PAY,
+            settings.GOOGLE_PAY,
         ]:
             source = gateway
             TapPayment.objects.create(
@@ -123,8 +125,9 @@ class OrderItemManager(models.Manager):
         inventory_price = (
             round(float(order_item.inventory.price), 3) if order_item.inventory else 0
         )
+        store = order_item.order.store
         attribute_choices_price = sum(
-            map(lambda item: float(item.price) or 0, attributes)
+            map(lambda item: float(item.get_price(store)) or 0, attributes)
         )
         total_price = round(
             (inventory_price + attribute_choices_price) * int(order_item.quantity), 3
@@ -134,7 +137,10 @@ class OrderItemManager(models.Manager):
             "product_variant": f"{order_item.product_variant.product.name} {order_item.product_variant.name}",
             "quantity": order_item.quantity,
             "attribute_choices": [
-                {"name": attribute.name, "price": round(float(attribute.price), 3)}
+                {
+                    "name": attribute.name,
+                    "price": round(float(attribute.get_price(store)), 3),
+                }
                 for attribute in attributes
             ],
             "total_price": total_price,
@@ -150,7 +156,23 @@ class OrderManager(models.Manager):
         from ob_dj_store.apis.stores.rest.serializers.serializers import (
             OrderDataSerializer,
         )
+        from ob_dj_store.core.stores.models._partner import PartnerAuthInfo
 
+        try:
+            partner_auth_info = PartnerAuthInfo.objects.get(
+                user=kwargs["customer"],
+                authentication_expires__gte=now(),
+                partner__offer_start_time__lte=now(),
+                partner__offer_end_time__gt=now(),
+            )
+        except ObjectDoesNotExist:
+            partner_auth_info = None
+        if partner_auth_info:
+            partner = partner_auth_info.partner
+            store = kwargs.get("store", None)
+            if store:
+                if partner.stores.filter(pk=kwargs["store"].pk).exists():
+                    kwargs["discount"] = partner.discount
         order = super().create(**kwargs)
         serializer = OrderDataSerializer(order)
         order.init_data = serializer.data
@@ -254,3 +276,12 @@ class WalletTransactionManager(models.Manager):
         if type == WalletTransaction.TYPE.DEBIT and wallet.balance < kwargs["amount"]:
             raise ValidationError(_("Insufficient Funds"))
         return super().create(*args, **kwargs)
+
+
+class PartnerAuthInfoManager(models.Manager):
+    def create(self, *args, **kwargs):
+        return super().create(*args, **kwargs)
+
+
+class CountryPaymentMethodManager(ActiveMixin, models.Manager):
+    pass
