@@ -8,6 +8,13 @@ from ob_dj_store.core.stores.models._feedback import (
 )
 from ob_dj_store.core.stores.models._inventory import Inventory, InventoryOperations
 from ob_dj_store.core.stores.models._order import Order, OrderHistory, OrderItem
+from ob_dj_store.core.stores.models._partner import (
+    Discount,
+    Partner,
+    PartnerAuthInfo,
+    PartnerEmailDomain,
+    PartnerOTPAuth,
+)
 from ob_dj_store.core.stores.models._payment import Payment, Tax
 from ob_dj_store.core.stores.models._product import (
     Attribute,
@@ -23,6 +30,7 @@ from ob_dj_store.core.stores.models._product import (
     StoreAttributeChoice,
 )
 from ob_dj_store.core.stores.models._store import (
+    CountryPaymentMethod,
     OpeningHours,
     PaymentMethod,
     PhoneContact,
@@ -71,4 +79,10 @@ __all__ = [
     "AvailabilityHours",
     "StoreAttributeChoice",
     "Menu",
+    "PartnerEmailDomain",
+    "Partner",
+    "PartnerAuthInfo",
+    "PartnerOTPAuth",
+    "Discount",
+    "CountryPaymentMethod",
 ]
