@@ -17,9 +17,11 @@ class Favorite(DjangoModelCleanMixin, models.Model):
         get_user_model(), related_name="favorites", on_delete=models.CASCADE
     )
     name = models.CharField(max_length=200, null=True, blank=True)
+    name_arabic = models.CharField(max_length=200, null=True, blank=True)
     content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
     content_object = GenericForeignKey("content_type", "object_id")
     object_id = models.PositiveIntegerField()
+    extra_info = models.TextField(blank=True, null=True)
     # Audit fields
     created_on = models.DateTimeField(auto_now_add=True)
     objects = FavoriteManager()
@@ -33,13 +35,14 @@ class Favorite(DjangoModelCleanMixin, models.Model):
         return f"{self.user} favorites {self.content_object}"
 
     @classmethod
-    def add_favorite(cls, content_object, user, name, extras=[]):
+    def add_favorite(cls, content_object, user, name, extra_info=None, extras=[]):
         content_type = ContentType.objects.get_for_model(type(content_object))
         favorite = Favorite(
             user=user,
             content_type=content_type,
             object_id=content_object.pk,
             content_object=content_object,
+            extra_info=extra_info,
             name=name,
         )
         favorite.save()
@@ -52,10 +55,12 @@ class Favorite(DjangoModelCleanMixin, models.Model):
             )
         return favorite
 
-    def update_favorite(self, name, extras=[]):
+    def update_favorite(self, name, extra_info=None, extras=[]):
         from ob_dj_store.core.stores.models._favorite import FavoriteExtra
 
         self.name = name
+        if extra_info:
+            self.extra_info = extra_info
         self.save()
         FavoriteExtra.objects.filter(favorite=self).delete()
         for extra in extras:
