@@ -1,7 +1,7 @@
 from decimal import Decimal
 
 from django.contrib.auth import get_user_model
-from django.core.exceptions import ObjectDoesNotExist
+from django.core.exceptions import ObjectDoesNotExist, ValidationError
 from django.core.validators import MinValueValidator
 from django.db import models
 from django.utils.translation import gettext_lazy as _
@@ -37,6 +37,9 @@ class Order(DjangoModelCleanMixin, models.Model):
     # TODO: Probably we want to setup the on_delete to SET_NULL because orders is part of
     #       sales and even if a user deleted orders cannot disappear otherwise will reflect
     #       invalid sales figure; same can be applied for the store field
+    discount = models.ForeignKey(
+        "stores.Discount", on_delete=models.PROTECT, null=True, blank=True
+    )
     customer = models.ForeignKey(
         get_user_model(),
         related_name="orders",
@@ -126,6 +129,10 @@ class Order(DjangoModelCleanMixin, models.Model):
         self.status = Order.OrderStatus.READY
         self.save()
 
+    @property
+    def get_discount_amount(self):
+        return sum(map(lambda item: item.discount_offer_amount, self.items.all()))
+
     @property
     def total_amount(self):
         if self.type_of_order == Order.OrderType.WALLET.value:
@@ -137,6 +144,7 @@ class Order(DjangoModelCleanMixin, models.Model):
         )
         if self.shipping_method:
             amount += self.shipping_method.shipping_fee
+        amount -= self.get_discount_amount
         return amount
 
     @property
@@ -207,10 +215,28 @@ class OrderItem(DjangoModelCleanMixin, models.Model):
     @property
     def attribute_choices_total_amount(self):
         total_price = Decimal(0)
+        store = self.order.store
+        if self.order.type_of_order == Order.OrderType.PHYSICAL.value and not store:
+            raise ValidationError("Physical Order should have store object")
         for attribute_choice in self.attribute_choices.all():
-            total_price += attribute_choice.price
+            try:
+                attribute_inventory = attribute_choice.attribute_inventory.get(
+                    store=store
+                )
+            except ObjectDoesNotExist:
+                raise ValidationError(
+                    f"AttributeChoice(PK={attribute_choice.id}) does not have Inventory at Store(PK={store.id})"
+                )
+            total_price += attribute_inventory.price
         return total_price
 
+    @property
+    def discount_offer_amount(self):
+        discount = self.order.discount
+        if discount:
+            return discount.perc_to_flat(self.total_amount)
+        return Decimal(0)
+
     @property
     def total_amount(self):
         if self.total_price > 0:
