@@ -70,8 +70,9 @@ class Payment(models.Model):
 
     user = models.ForeignKey(
         settings.AUTH_USER_MODEL,
-        on_delete=models.DO_NOTHING,
+        on_delete=models.SET_NULL,
         null=True,
+        related_name="user_payments",
     )
     status = models.CharField(
         max_length=100,
@@ -159,7 +160,9 @@ class Payment(models.Model):
         )
         if not self.payment_tax:
             return sum_orders
-        if self.payment_tax.rate == Tax.Rates.PERCENTAGE:
+        elif not self.payment_tax.is_applied:
+            return sum_orders
+        elif self.payment_tax.rate == Tax.Rates.PERCENTAGE:
             perc = Decimal(sum_orders * self.payment_tax.value / 100)
             return round(sum_orders + perc, 3)
 
