@@ -25,7 +25,11 @@ class Category(DjangoModelCleanMixin, models.Model):
 
     is_active = models.BooleanField(default=False)
     name = models.CharField(max_length=200, help_text=_("Name"))
+    name_arabic = models.CharField(
+        max_length=200, null=True, blank=True, help_text=_("Name in Arabic")
+    )
     description = models.TextField(null=True, blank=True)
+    description_arabic = models.TextField(null=True, blank=True)
     # parent for allowing subcategories
     parent = models.ForeignKey(
         "self",
@@ -69,6 +73,7 @@ class Menu(DjangoModelCleanMixin, models.Model):
     store = models.OneToOneField(Store, on_delete=models.CASCADE, related_name="menu")
     categories = models.ManyToManyField(Category, related_name="menus")
     name = models.CharField(max_length=255, null=True, blank=True)
+    name_arabic = models.CharField(max_length=255, null=True, blank=True)
 
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
@@ -93,7 +98,19 @@ class AvailabilityHours(DjangoModelCleanMixin, models.Model):
         SATURDAY = 6, _("Saturday")
         SUNDAY = 7, _("Sunday")
 
+    class WeekdaysArabic(models.IntegerChoices):
+        MONDAY = 1, _("الاثنين")
+        TUESDAY = 2, _("الثلاثاء")
+        WEDNESDAY = 3, _("الأربعاء")
+        THURSDAY = 4, _("الخميس")
+        FRIDAY = 5, _("الجمعة")
+        SATURDAY = 6, _("السبت")
+        SUNDAY = 7, _("الأحد")
+
     weekday = models.IntegerField(choices=Weekdays.choices)
+    weekday_arabic = models.IntegerField(
+        null=True, blank=True, choices=WeekdaysArabic.choices
+    )
     from_hour = models.TimeField()
     to_hour = models.TimeField()
     store = models.ForeignKey(
@@ -137,6 +154,7 @@ class ProductTag(models.Model):
     """
 
     name = models.CharField(max_length=500)
+    name_arabic = models.CharField(max_length=500, null=True, blank=True)
     text_color = models.CharField(
         default="#000000",
         max_length=7,
@@ -176,11 +194,22 @@ class Product(DjangoModelCleanMixin, models.Model):
         DIGITAL = "DIGITAL", _("digital")
 
     name = models.CharField(max_length=200, help_text=_("Name"), unique=True)
+    name_arabic = models.CharField(
+        max_length=200,
+        null=True,
+        blank=True,
+        help_text=_("Name in arabic"),
+        unique=True,
+    )
     slug = models.SlugField(max_length=255, unique=True)
     label = models.CharField(
         max_length=200, help_text=_("Label"), null=True, blank=True
     )
+    label_arabic = models.CharField(
+        max_length=200, help_text=_("Label in Arabic"), null=True, blank=True
+    )
     description = models.TextField(null=True, blank=True)
+    description_arabic = models.TextField(null=True, blank=True)
     # TODO: A product can be assigned to multiple categories
     category = models.ManyToManyField(
         Category,
@@ -229,6 +258,9 @@ class Attribute(DjangoModelCleanMixin, models.Model):
     """
 
     name = models.CharField(max_length=200, help_text=_("Name"))
+    name_arabic = models.CharField(
+        max_length=200, null=True, blank=True, help_text=_("Name in Arabic")
+    )
 
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
@@ -250,23 +282,33 @@ class AttributeChoice(DjangoModelCleanMixin, models.Model):
     plu = models.CharField(max_length=40, unique=True, null=True, blank=True)
     external_id = models.CharField(max_length=40, unique=True, null=True, blank=True)
     name = models.CharField(max_length=200, help_text=_("Name"))
-    price = models.DecimalField(
-        max_digits=10, decimal_places=3, default=0, help_text=_("Price")
+    name_arabic = models.CharField(
+        max_length=200, null=True, blank=True, help_text=_("Name in Arabic")
     )
     description = models.TextField(null=True, blank=True)
+    description_arabic = models.TextField(null=True, blank=True)
     order_value = models.PositiveSmallIntegerField(
         verbose_name=_("ordering"), default=1
     )
     is_default = models.BooleanField(default=False)
     label = models.CharField(max_length=200, null=True, blank=True)
+    label_arabic = models.CharField(max_length=200, null=True, blank=True)
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
 
+    def get_price(self, store):
+        try:
+            return self.attribute_inventory.get(store=store).price
+        except ObjectDoesNotExist:
+            raise ValidationError(
+                f"AttributeChoice(PK={self.pk} doesnt have inventory at Store(PK={store.pk}))"
+            )
+
     class Meta:
         verbose_name = _("Attribute Choice")
         verbose_name_plural = _("Attribute Choices")
-        ordering = ["price", "order_value", "created_at"]
+        ordering = ["order_value", "created_at"]
 
     def __str__(self):
         return f"{self.name}: Attribute Choice  (PK={self.pk})"
@@ -285,11 +327,17 @@ class StoreAttributeChoice(models.Model):
     snooze_end_date = models.DateTimeField(
         default=now, help_text=_("When snooze status should end")
     )
+    price = models.DecimalField(
+        max_digits=10, decimal_places=3, default=0, help_text=_("Price")
+    )
 
     class Meta:
         verbose_name = _("Store Attribute Choice")
         verbose_name_plural = _("Store Attribute Choices")
         unique_together = (("store", "attribute"),)
+        ordering = [
+            "price",
+        ]
 
     def __str__(self) -> str:
         return f"StoreProductAttribute(PK={self.pk})"
@@ -311,7 +359,11 @@ class ProductAttribute(DjangoModelCleanMixin, models.Model):
         INCREMENT_CHOICE = "INCREMENT_CHOICE", _("increment choice")
 
     name = models.CharField(max_length=200, help_text=_("Name"))
+    name_arabic = models.CharField(
+        max_length=200, null=True, blank=True, help_text=_("Name in Arabic")
+    )
     description = models.TextField(null=True, blank=True)
+    description_arabic = models.TextField(null=True, blank=True)
 
     attribute_choices = models.ManyToManyField(
         AttributeChoice, related_name="product_attributes", blank=True
@@ -330,6 +382,7 @@ class ProductAttribute(DjangoModelCleanMixin, models.Model):
     plu = models.CharField(max_length=40, unique=True, null=True, blank=True)
     external_id = models.CharField(max_length=40, unique=True, null=True, blank=True)
     label = models.CharField(max_length=200, null=True, blank=True)
+    label_arabic = models.CharField(max_length=200, null=True, blank=True)
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
@@ -350,8 +403,15 @@ class ProductVariant(DjangoModelCleanMixin, models.Model):
     """
 
     name = models.CharField(max_length=200, help_text=_("Name"))
+    name_arabic = models.CharField(
+        max_length=200, null=True, blank=True, help_text=_("Name in Arabic")
+    )
     label = models.CharField(max_length=50, help_text=_("Label"), null=True, blank=True)
+    label_arabic = models.CharField(
+        max_length=50, help_text=_("Label in arabic"), null=True, blank=True
+    )
     description = models.TextField(null=True, blank=True)
+    description_arabic = models.TextField(null=True, blank=True)
     product = models.ForeignKey(
         Product, related_name="product_variants", on_delete=models.CASCADE
     )
