@@ -52,6 +52,7 @@ class Wallet(models.Model):
         related_name="wallets",
     )
     name = models.CharField(max_length=200, null=True, blank=True)
+    name_arabic = models.CharField(max_length=200, null=True, blank=True)
     media_image = models.ForeignKey(
         WalletMedia,
         on_delete=models.SET_NULL,
@@ -161,6 +162,7 @@ class WalletTransaction(models.Model):
         decimal_places=settings.DEFAULT_DECIMAL_PLACES,
     )
 
+    is_by_admin = models.BooleanField(default=False)
     is_cashback = models.BooleanField(default=False)
     is_refund = models.BooleanField(default=False)
 
